/* $Id: MenuB.h,v 1.5 1998/11/22 15:42:50 glgay Exp $ */
/*
 Copyright (C) 1993, 1994 Jettero Heller
 Copyright (C) 1994, 1995 Peter Williams
 
 This library is free software; you can redistribute it and/or
 modify it under the terms of the GNU Library General Public License 
 version 2 as published by the Free Software Foundation.

 This library is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 Library General Public License for more details.

 You should have received a copy of the GNU Library General Public
 License along with this library; see the file COPYING.  If not,
 write to the Free Software Foundation, Inc., 675 Mass Ave, 
 Cambridge, MA 02139, USA.
*/


#if !defined(_XARM_MENUB_H_)
#define _XARM_MENUB_H_

/* Include(s): */
#include <Xarm/RowColumn.h>
#include <Xarm/CascadeB.h>

class MenuButton : public PulldownMenu {

 public:
   CascadeButton *button;
   MenuButton(Widget w_parent, char *str, KeySym mn = 0, _XtString name = NULL);
   MenuButton(_XtString name, Widget w_parent);
   virtual ~MenuButton() { delete button; }
};

#endif
